

.. _sphx_glr_auto_examples_evaluation:

.. _evaluation_examples:

Evaluation examples
-------------------

Examples illustrating how classification using imbalanced dataset can be done.



.. raw:: html

    <div class="sphx-glr-thumbnails">


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Specific metrics have been developed to evaluate classifier which has been trained using imbala...">

.. only:: html

  .. image:: /auto_examples/evaluation/images/thumb/sphx_glr_plot_classification_report_thumb.png
    :alt:

  :ref:`sphx_glr_auto_examples_evaluation_plot_classification_report.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Evaluate classification by compiling a report</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Specific metrics have been developed to evaluate classifier which has been trained using imbala...">

.. only:: html

  .. image:: /auto_examples/evaluation/images/thumb/sphx_glr_plot_metrics_thumb.png
    :alt:

  :ref:`sphx_glr_auto_examples_evaluation_plot_metrics.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Metrics specific to imbalanced learning</div>
    </div>


.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/evaluation/plot_classification_report
   /auto_examples/evaluation/plot_metrics

